"""Shared exception. Here because I want to have one root exception type"""


class PIMSError(Exception):
    pass
